
from typing import TypeVar, List, Any
from functools import reduce
import textwrap

T = TypeVar("T")

def wrap(txt: str) -> str:
    return ["\n".join(textwrap.wrap(l, width = 72)) for l in txt.split("\n")]

def deduplicate(l: List[Any])-> List[T]:
    def _dup(a,b):
        if len(a) == 0:
            return [b]
        elif a[-1] == b:
            return a
        else:
            return a + [b]

    return reduce(_dup, l, [])

def process(text):
    return "\n".join(deduplicate(wrap(text)))



from typing import Optional
import css_inline
import jinja2
from cc_email_templates import txt_processing

env = jinja2.Environment(
        loader = jinja2.PackageLoader("cc_email_templates", "templates"),
        autoescape = jinja2.select_autoescape()
    )

inliner = css_inline.CSSInliner()

def call_to_action_email(
        title:              str,
        content_above:      str,
        action_button_text: str,
        action_link:        str,
        content_below:      Optional[str] = None,
        unsub_link:         Optional[str] = None,
        address:            Optional[str] = None,
        sender:             Optional[str] = None
        ) -> str:
    """
    call_to_action_email
    ====================

    parameters:
        title              (str)
        content_above      (str)
        content_below      (str)
        action_button_text (str)
        action_link        (str)
        unsub_link         (Optional[str])
        address            (Optional[str])

    returns:
        str: Compiled template
    """
    html = env.get_template("simple-call-to-action.html.j2").render(
            title              = title,
            content_above      = content_above,
            content_below      = content_below,
            action_link        = action_link,
            action_button_text = action_button_text,
            unsub_link         = unsub_link,
            address            = address,
            sender             = sender)

    txt = env.get_template("simple-call-to-action.txt.j2").render(
            title              = title,
            content_above      = content_above,
            content_below      = content_below,
            action_link        = action_link,
            action_button_text = action_button_text,
            unsub_link         = unsub_link,
            address            = address,
            sender             = sender)

    return txt_processing.process(txt), inliner.inline(html)



# -*- coding: utf-8 -*-
from setuptools import setup

packages = \
['cc_email_templates', 'cc_email_templates.templates']

package_data = \
{'': ['*']}

install_requires = \
['Jinja2>=3.0.3,<4.0.0', 'css-inline>=0.8.1,<0.9.0']

setup_kwargs = {
    'name': 'cc-email-templates',
    'version': '0.1.0',
    'description': '',
    'long_description': None,
    'author': 'peder2911',
    'author_email': 'pglandsverk@gmail.com',
    'maintainer': None,
    'maintainer_email': None,
    'url': None,
    'packages': packages,
    'package_data': package_data,
    'install_requires': install_requires,
    'python_requires': '>=3.8,<4.0',
}


setup(**setup_kwargs)
